==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/FirstStart/ts/FirstStart_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+35"/>
        <source>%1 First Start</source>
        <translation>%1 初回実行</translation>
    </message>
    <message>
        <location line="+185"/>
        <source>Black</source>
        <translation>黒</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>白</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Language:</source>
        <translation>言語:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welcome to %1</source>
        <translation>ようこそ %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translation>新規図面の設定を選択してください。これらの設定は後で設定ダイアログで変更できます。</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translation>単位:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translation>デフォルト用紙サイズ:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translation>小数点:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translation>背景色:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/FirstStart/ts/FirstStart_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+35"/>
        <location line="+216"/>
        <source>%1 First Start</source>
        <translation>%1 初回実行</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Black</source>
        <translation>黒</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>白</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Language:</source>
        <translation>言語:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welcome to %1</source>
        <translation>ようこそ %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translation>新規図面の設定を選択してください。これらの設定は後で設定ダイアログで変更できます。</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translation>単位:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translation>デフォルト用紙サイズ:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translation>小数点:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translation>背景色:</translation>
    </message>
</context>
</TS>
